@@ -29,11 +29,7 @@ import re
 import types
 import email.Utils
 
-# Only on Unix
-try:
-    import pwd
-except ImportError:
-    pass
+import pwd
 
 from exceptions import *
 from utilities import *
@@ -106,10 +102,6 @@ class Maildir(DeliverySkeleton, ForkingBase):
 
       path - path to maildir, which will be expanded for leading '~/' or
       '~USER/', as well as environment variables.
-
-    getmail will attempt to chown the file created to the UID and GID of the
-    maildir.  If this fails (i.e. getmail does not have sufficient permissions),
-    no error is raised.
     '''
     _confitems = (
         {'name' : 'path', 'type' : str},
@@ -125,9 +117,6 @@ class Maildir(DeliverySkeleton, ForkingBase):
         if not self.conf['path'].endswith('/'):
             raise getmailConfigurationError('maildir path missing trailing /'
                 ' (%s)' % self.conf['path'])
-        if not is_maildir(self.conf['path']):
-            raise getmailConfigurationError('not a maildir (%s)'
-                % self.conf['path'])
 
     def __str__(self):
         self.log.trace()
@@ -144,10 +133,14 @@ class Maildir(DeliverySkeleton, ForkingBase):
             if os.name == 'posix':
                 if uid:
                     change_uidgid(None, uid, gid)
-                if os.geteuid() == 0 or os.getegid() == 0:
+                if os.geteuid() == 0:
                     raise getmailConfigurationError(
                         'refuse to deliver mail as root'
                     )
+                if os.getegid() == 0:
+                    raise getmailConfigurationError(
+                        'refuse to deliver mail as GID 0'
+                    )
             f = deliver_maildir(self.conf['path'], msg.flatten(delivered_to,
                 received), self.hostname, self.dcount)
             stdout.write(f)
@@ -172,9 +165,14 @@ class Maildir(DeliverySkeleton, ForkingBase):
                 # Config specifies delivery as user other than current UID
                 uid = uid_of_user(user)
                 gid = gid_of_uid(uid)
-            if uid == 0 or gid == 0:
-                raise getmailConfigurationError(
-                    'refuse to deliver mail as root')
+                if uid == 0:
+                    raise getmailConfigurationError(
+                        'refuse to deliver mail as root'
+                    )
+                if gid == 0:
+                    raise getmailConfigurationError(
+                        'refuse to deliver mail as GID 0'
+                    )
         self._prepare_child()
         stdout = os.tmpfile()
         stderr = os.tmpfile()
@@ -228,22 +226,6 @@ class Mboxrd(DeliverySkeleton, ForkingBase):
     def initialize(self):
         self.log.trace()
         self.conf['path'] = expand_user_vars(self.conf['path'])
-        if not os.path.exists(self.conf['path']):
-            raise getmailConfigurationError('mboxrd does not exist (%s)'
-                % self.conf['path'])
-        if not os.path.isfile(self.conf['path']):
-            raise getmailConfigurationError('not an mboxrd file (%s)'
-                % self.conf['path'])
-        # Check if it _is_ an mbox file.  mbox files must start with "From "
-        # in their first line, or are 0-length files.
-        f = open(self.conf['path'], 'r+b')
-        lock_file(f)
-        first_line = f.readline()
-        unlock_file(f)
-        if first_line and first_line[:5] != 'From ':
-            # Not an mbox file; abort here
-            raise getmailConfigurationError('not an mboxrd file (%s)'
-                % self.conf['path'])
 
     def __str__(self):
         self.log.trace()
@@ -260,10 +242,22 @@ class Mboxrd(DeliverySkeleton, ForkingBase):
             if os.name == 'posix':
                 if uid:
                     change_uidgid(None, uid, gid)
-                if os.geteuid() == 0 or os.getegid() == 0:
+                if os.geteuid() == 0:
                     raise getmailConfigurationError(
                         'refuse to deliver mail as root'
                     )
+                if os.getegid() == 0:
+                    raise getmailConfigurationError(
+                        'refuse to deliver mail as GID 0'
+                    )
+
+            if not os.path.exists(self.conf['path']):
+                raise getmailDeliveryError('mboxrd does not exist (%s)'
+                    % self.conf['path'])
+            if not os.path.isfile(self.conf['path']):
+                raise getmailDeliveryError('not an mboxrd file (%s)'
+                    % self.conf['path'])
+
             # Open mbox file, refusing to create it if it doesn't exist
             fd = os.open(self.conf['path'], os.O_RDWR)
             status_old = os.fstat(fd)
@@ -276,7 +270,7 @@ class Mboxrd(DeliverySkeleton, ForkingBase):
             if first_line and first_line[:5] != 'From ':
                 # Not an mbox file; abort here
                 unlock_file(f)
-                raise getmailConfigurationError('not an mboxrd file (%s)'
+                raise getmailDeliveryError('not an mboxrd file (%s)'
                     % self.conf['path'])
             # Seek to end
             f.seek(0, 2)
@@ -344,9 +338,14 @@ class Mboxrd(DeliverySkeleton, ForkingBase):
                 # Config specifies delivery as user other than current UID
                 uid = uid_of_user(user)
                 gid = gid_of_uid(uid)
-            if uid == 0 or gid == 0:
+            if uid == 0:
                 raise getmailConfigurationError(
-                    'refuse to deliver mail as root')
+                    'refuse to deliver mail as root'
+                )
+            if gid == 0:
+                raise getmailConfigurationError(
+                    'refuse to deliver mail as GID 0'
+                )
         self._prepare_child()
         stdout = os.tmpfile()
         stderr = os.tmpfile()
@@ -497,7 +496,7 @@ class MDA_qmaillocal(DeliverySkeleton, ForkingBase):
             if ((os.geteuid() == 0 or os.getegid() == 0)
                     and not self.conf['allow_root_commands']):
                 raise getmailConfigurationError(
-                    'refuse to invoke external commands as root by default')
+                    'refuse to invoke external commands as root or GID 0 by default')
 
             os.execl(*args)
         except StandardError, o:
@@ -668,7 +667,7 @@ class MDA_external(DeliverySkeleton, ForkingBase):
             if ((os.geteuid() == 0 or os.getegid() == 0)
                     and not self.conf['allow_root_commands']):
                 raise getmailConfigurationError(
-                    'refuse to invoke external commands as root by default')
+                    'refuse to invoke external commands as root or GID 0 by default')
             args = [self.conf['path'], self.conf['path']]
             for arg in self.conf['arguments']:
                 arg = expand_user_vars(arg)
