@@ -13,12 +13,11 @@ import cStringIO
 import email
 import email.Errors
 import email.Utils
-import email.Parser
 from email.Generator import Generator
 
-from getmailcore.exceptions import *
-from getmailcore.utilities import mbox_from_escape, format_header, address_no_brackets
-import getmailcore.logging
+from exceptions import *
+from utilities import mbox_from_escape, format_header, address_no_brackets
+import logging
 
 message_attributes = (
     'sender',
@@ -30,7 +29,7 @@ message_attributes = (
 
 #######################################
 def corrupt_message(why, fromlines=None, fromstring=None):
-    log = getmailcore.logging.logger()
+    log = logging.logger()
     log.error('failed to parse retrieved message; constructing container for '
         'contents\n')
     if fromlines == fromstring == None:
@@ -80,27 +79,27 @@ class Message(object):
         self.received_from = None
         self.received_with = None
         self.__raw = None
-        parser = email.Parser.HeaderParser()
-        
+
         # Message is instantiated with fromlines for POP3, fromstring for
         # IMAP (both of which can be badly-corrupted or invalid, i.e. spam,
         # MS worms, etc).  It's instantiated with fromfile for the output
         # of filters, etc, which should be saner.
         if fromlines:
             try:
-                self.__msg = parser.parsestr(os.linesep.join(fromlines))
+                self.__msg = email.message_from_string(os.linesep.join(
+                    fromlines), strict=False)
             except email.Errors.MessageError, o:
                 self.__msg = corrupt_message(o, fromlines=fromlines)
             self.__raw = os.linesep.join(fromlines)
         elif fromstring:
             try:
-                self.__msg = parser.parsestr(fromstring)
+                self.__msg = email.message_from_string(fromstring, strict=False)
             except email.Errors.MessageError, o:
                 self.__msg = corrupt_message(o, fromstring=fromstring)
             self.__raw = fromstring
         elif fromfile:
             try:
-                self.__msg = parser.parse(fromfile)
+                self.__msg = email.message_from_file(fromfile, strict=False)
             except email.Errors.MessageError, o:
                 # Shouldn't happen
                 self.__msg = corrupt_message(o, fromstring=fromfile.read())
